==> haskell-pgp-wordlist-0.1.0.3-248-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pgp-wordlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pgp-wordlist
version:              0.1.0.3
visibility:           public
id:                   pgp-wordlist-0.1.0.3-JfgoL5LrARIXNyUxM2DIG
key:                  pgp-wordlist-0.1.0.3-JfgoL5LrARIXNyUxM2DIG
license:              BSD-3-Clause
copyright:            David Luposchainsky <dluposchainsky(λ)gmail.com>
maintainer:           David Luposchainsky <dluposchainsky(λ)gmail.com>
author:               David Luposchainsky <dluposchainsky(λ)gmail.com>
homepage:             https://github.com/quchen/pgp-wordlist
synopsis:
    Translate between binary data and a human-readable
    collection of words.

description:
    Translate between binary data and a human-readable
    collection of words.

    The PGP Word List consists of two phonetic alphabets, each
    with one word per possible byte value. A string of bytes
    is translated with these alphabets, alternating between
    them at each byte.

    The PGP words corresponding to the bytes @5B 1D CA 6E@
    are "erase breakaway spellbind headwaters", for example.

    For further information, see
    <http://en.wikipedia.org/wiki/PGP_word_list Wikipedia>.

category:             Data, Serialization
abi:                  779b4fa1d13e53ff78022645eaa6108c
exposed:              True
exposed-modules:
    Data.Text.PgpWordlist Data.Text.PgpWordlist.Internal.AltList
    Data.Text.PgpWordlist.Internal.Convert
    Data.Text.PgpWordlist.Internal.Types
    Data.Text.PgpWordlist.Internal.Word8Bimap
    Data.Text.PgpWordlist.Internal.Words

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pgp-wordlist-0.1.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pgp-wordlist-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pgp-wordlist
hs-libraries:         HSpgp-wordlist-0.1.0.3-JfgoL5LrARIXNyUxM2DIG
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1 text-1.2.5.0
    vector-0.13.1.0-IOwb1qSGKSdHIyg7Qp7MNu

haddock-interfaces:
    /usr/share/doc/haskell-pgp-wordlist/html/pgp-wordlist.haddock

haddock-html:         /usr/share/doc/haskell-pgp-wordlist/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pgp-wordlist-0.1.0.3-250-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pgp-wordlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pgp-wordlist
version:              0.1.0.3
visibility:           public
id:                   pgp-wordlist-0.1.0.3-6nq4D88bmC57mq8XBU0Ulh
key:                  pgp-wordlist-0.1.0.3-6nq4D88bmC57mq8XBU0Ulh
license:              BSD-3-Clause
copyright:            David Luposchainsky <dluposchainsky(λ)gmail.com>
maintainer:           David Luposchainsky <dluposchainsky(λ)gmail.com>
author:               David Luposchainsky <dluposchainsky(λ)gmail.com>
homepage:             https://github.com/quchen/pgp-wordlist
synopsis:
    Translate between binary data and a human-readable
    collection of words.

description:
    Translate between binary data and a human-readable
    collection of words.

    The PGP Word List consists of two phonetic alphabets, each
    with one word per possible byte value. A string of bytes
    is translated with these alphabets, alternating between
    them at each byte.

    The PGP words corresponding to the bytes @5B 1D CA 6E@
    are "erase breakaway spellbind headwaters", for example.

    For further information, see
    <http://en.wikipedia.org/wiki/PGP_word_list Wikipedia>.

category:             Data, Serialization
abi:                  cdcd43568e0ab76727e8d52682f35718
exposed:              True
exposed-modules:
    Data.Text.PgpWordlist Data.Text.PgpWordlist.Internal.AltList
    Data.Text.PgpWordlist.Internal.Convert
    Data.Text.PgpWordlist.Internal.Types
    Data.Text.PgpWordlist.Internal.Word8Bimap
    Data.Text.PgpWordlist.Internal.Words

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pgp-wordlist-0.1.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pgp-wordlist-0.1.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pgp-wordlist-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pgp-wordlist
hs-libraries:         HSpgp-wordlist-0.1.0.3-6nq4D88bmC57mq8XBU0Ulh
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    vector-0.13.1.0-3m7HMvWbOJNDnUiYgFdHrI

haddock-interfaces:
    /usr/share/doc/haskell-pgp-wordlist/html/pgp-wordlist.haddock

haddock-html:         /usr/share/doc/haskell-pgp-wordlist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
